@@ -2,6 +2,6 @@
 
 __author__ = 'Federico Repond'
 __email__ = 'federico.repond@leapsight.com'
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
-__all__ = ['xapo_utils', 'xapo_tools']
+__all__ = ['xapo_utils', 'xapo_tools', 'xapo_api']
